package com.example.external_app_launcher

import android.app.Activity
import android.content.ComponentName
import android.content.Intent
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** ExternalAppLauncherPlugin */
class ExternalAppLauncherPlugin : FlutterPlugin, MethodCallHandler, Activity() {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "external_app_launcher")
        channel.setMethodCallHandler(this)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {


        if (call.method == "externalAppLauncher") {
            val packageName :String = call.argument("packageName")
            val appIntent: Intent = Intent(Intent.ACTION_MAIN, null)
            appIntent.addCategory(Intent.CATEGORY_HOME)
            appIntent.component =
                ComponentName(packageName, packageName)
            appIntent.flags = Intent.FLAG_ACTIVITY_NEW_TASK;
            startActivity(appIntent)
        }

        if (call.method == "getPlatformVersion") {
            result.success("Android ${android.os.Build.VERSION.RELEASE}")
        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }
}
